#!/usr/bin/env python
# Copyright (c) 2009, Willow Garage, Inc.
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the Willow Garage, Inc. nor the names of its
#       contributors may be used to endorse or promote products derived from
#       this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

## %Tag(PYTHON_CLIENT)%

import roslib; roslib.load_manifest('warehouse')
import rospy
from std_msgs.msg import String
from warehouse.srv import *
from warehouse.msg import Condition
from warehouse.exceptions import *

import warehouse 

def insert_cb(msg):
  print "Data was inserted by {0}".format(msg.sender)


rospy.init_node('warehouse_client')

# Create a client interface to the Warehouse
wc = warehouse.Client()

# See if a database and collection exist
(db_exists, collection_exists) = wc.has_collection("my_db", "my_collection")

if db_exists:
  print "Database[my_db], already exists"
else:
  print "Database[my_db], does not exist"

if collection_exists:
  print "Collection[my_collection] in Database[my_db], already exists"
else:
  print "Collection[my_collection] in Database[my_db], does not exist"
 
# Create a connection to a collection. This will create the collection if 
# it doesn't already exist
try:
  collection = wc.setup_collection("my_db", "my_collection", String, ["data"])
except ClientException:
  rospy.logerr("Unable to create a connection to the database")

# Register a function callback to data insertion
collection.subscribe_to_insertion(insert_cb)

print "Pushing data"
# Push data into the database
collection.push_data(String("Here"))

print "Querying"
# Create a query, and get a list of the results
conditions = []
conditions.append(Condition("data", Condition.EQUALS, ["Here"]))
result = collection.query( conditions )
print "Query result: {0}".format(result)

# Drop our database if we are done with it
wc.drop_db("my_db")


## %Tag(PYTHON_CLIENT)%
