/*
 * Copyright (c) 2008, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

/**
 * \file 
 * 
 * Implementation of non-templated methods of WarehouseClient
 *
 * \author Bhaskara Marthi
 */

#include <warehouse/warehouse_client.h>
#include <warehouse/SetupCollection.h>
#include <warehouse/InitiateQuery.h>
#include <warehouse/PullMessage.h>
#include <warehouse/ListCollections.h>
#include <warehouse/Metadata.h>
#include <warehouse/RemoveMessages.h>

namespace warehouse
{

using std::string;
using std::vector;
using boost::format;


WarehouseClient::WarehouseClient (const string& db) :
  db_(db), 
  setup_client_(nh_.serviceClient<SetupCollection>("setup_collection")),
  list_collections_client_(nh_.serviceClient<ListCollections>("list_collections"))
{
  waitForService(setup_client_);
  waitForService(list_collections_client_);
}


vector<string>
WarehouseClient::listCollections () const
{
  ListCollections srv;
  srv.request.db_name = db_;
  if (!list_collections_client_.call(srv))
    throw WarehouseClientException("Service call to list_collections failed");
  if (!srv.response.db_exists)
    return vector<string>();
  else
    return srv.response.collections;
}

string WarehouseClient::dbName () const
{
  return db_;
}



} // namespace
